summaryrefslogtreecommitdiff
path: root/src/argb_frame.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-01-17 19:44:58 +0000
committerCarl Hetherington <cth@carlh.net>2013-01-17 19:44:58 +0000
commit369ba52fe8b3ddeda734692541471c402016a18d (patch)
treef140d572d97f1bb27d0713160247457c767cc101 /src/argb_frame.cc
parent62ee85a258aa9329544d8542dfbcc40ce8177a7a (diff)
Use new Size struct.
Diffstat (limited to 'src/argb_frame.cc')
-rw-r--r--src/argb_frame.cc14
1 files changed, 6 insertions, 8 deletions
diff --git a/src/argb_frame.cc b/src/argb_frame.cc
index 8e54e3b4..a48f80bb 100644
--- a/src/argb_frame.cc
+++ b/src/argb_frame.cc
@@ -21,16 +21,14 @@
using namespace libdcp;
/** Construct an empty ARGBFrame with a given width and height and with
* undefined contents.
* @param width Width in pixels.
* @param height Height in pixels.
*/
-ARGBFrame::ARGBFrame (int width, int height)
- : _width (width)
- , _height (height)
+ARGBFrame::ARGBFrame (Size size)
+ : _size (size)
{
- _data = new uint8_t[width * height * 4];
+ _data = new uint8_t[_size.width * _size.height * 4];
}
@@ -43,5 +41,5 @@ ARGBFrame::~ARGBFrame ()
int
ARGBFrame::stride () const
{
- return _width * 4;
+ return _size.width * 4;
}
@@ -21,16 +21,14 @@
using namespace libdcp;
-/** Construct an empty ARGBFrame with a given width and height and with
+/** Construct an empty ARGBFrame of a given size and with
* undefined contents.
@@ -21,16 +21,14 @@
* undefined contents.
- * @param width Width in pixels.
- * @param height Height in pixels.
+ * @param size Size in pixels.
*/